/* process response from /dev/tty (K+P version 2).
 * $Id: ttyin2.c,v 1.3 2002/03/06 00:37:53 ian Exp $
 */

#include <stdio.h>
#include <stdlib.h>
#include "zap.h"

int
ttyin()	
{
	char buf[BUFSIZ];
	FILE *efopen();
	static FILE *tty = NULL;

	if (tty == NULL)
		tty = efopen("/dev/tty", "r");
	for (;;) {
		if (fgets(buf,BUFSIZ,tty) == NULL || buf[0] == 'q')
			exit(0);
		else if (buf[0] == '!') {
			system(buf+1);	/* BUG here */
			printf("!\n");
		}
		else	/* ordinary line */
			return buf[0];
	}
}
